#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_OR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_OR_HPP_INCLUDED

#include <nt2/operator/include/functions/logical_or.hpp>

#endif
